==> bnctool-0.1.0.tgz: package/bin/bnc-init.js <==
#!/usr/bin/env node

var download = require('download-git-repo');
var program = require('commander');
var chalk = require('chalk');
var path = require('path');
var util = require('util');
var file = require('../lib/file');
var logger = require('../lib/logger');

var Init = {
    name: null,
    baseDir: process.cwd(),
    workDir: null,
    workList: []
};

/**
 * Usage.
 */

program
    .usage('<project-name>');

/**
 * Help.
 */

program.on('--help', function () {
    console.log('  Examples:');
    console.log();
    console.log(chalk.green('    # create a new project with an official template'));
    console.log('    $ bnc init my-project');
    console.log();
});

process.on('exit', function () {
    console.log();
});

program.parse(process.argv);
if (program.args.length < 1) {
    program.help();
    return;
}

Init.init = function () {
    this.name = program.args[0];
    this.workDir = path.join(this.baseDir, this.name);
    file.mkdir(this.workDir);
    logger.log('create directory success -> ' + this.workDir);
    Init.download();
};

Init.download = function () {
    logger.log('Start downloading the code. Please wait for a minute!');

    download('BaiduBnc/bnc-project', this.workDir, function (err) {
        if(err) {
            logger.fatal(err);
        } else {
            logger.log('Download complete!');
            Init.process();
        }
    });
};

Init.process = function () {
    logger.log('Start initialization');

    var self = this;
    Init.workList = file.scanDirectory(this.workDir);
    Init.makeHTML();
    Init.workList.forEach(function (item) {
        if(/bncDemo/.test(item)) {
            var newPath = item.replace('bncDemo', self.name);
            file.rename(item, newPath, function () {
                file.replace(newPath, 'bncDemo', self.name);
            });
        } else {
            file.replace(item, 'bncDemo', self.name);
        }
    });
};

Init.makeHTML = function () {
    var name = path.join(this.workDir, 'debug', 'test.html');
    var cmd = util.format('BNC.ability.%s.init()', Init.name);
    var content = file.read(name);
    var writeContent = content
        .replace('{{title}}', Init.name)
        .replace('{{caller}}', cmd);
    file.write(name, writeContent);

    logger.log('You can preview in -> ' + name);
    logger.log('use "bnc build" to debug the code');
};

Init.init();

==> bnctool-0.1.1.tgz: package/bin/bnc-init.js <==
#!/usr/bin/env node

var download = require('download-git-repo');
var program = require('commander');
var chalk = require('chalk');
var path = require('path');
var util = require('util');
var file = require('../lib/file');
var logger = require('../lib/logger');

var Init = {
    name: null,
    baseDir: process.cwd(),
    workDir: null,
    workList: []
};

/**
 * Usage.
 */

program
    .usage('<project-name>');

/**
 * Help.
 */

program.on('--help', function () {
    console.log('  Examples:');
    console.log();
    console.log(chalk.green('    # create a new project with an official template'));
    console.log('    $ bnc init my-project');
    console.log();
});

process.on('exit', function () {
    console.log();
});

program.parse(process.argv);
if (program.args.length < 1) {
    program.help();
    return;
}

Init.init = function () {
    this.name = program.args[0];
    this.workDir = path.join(this.baseDir, this.name);
    file.mkdir(this.workDir);
    logger.log('create directory success -> ' + this.workDir);
    Init.download();
};

Init.download = function () {
    logger.log('Start downloading the code. Please wait for a minute!');

    download('BaiduBnc/bnc-project', this.workDir, function (err) {
        if(err) {
            logger.fatal(err);
        } else {
            logger.log('Download complete!');
            Init.process();
        }
    });
};

Init.process = function () {
    logger.log('Start initialization...');

    var self = this;
    Init.workList = file.scanDirectory(this.workDir);
    Init.makeHTML();
    Init.workList.forEach(function (item) {
        if(/bncDemo/.test(item)) {
            var newPath = item.replace('bncDemo', self.name);
            file.rename(item, newPath, function () {
                file.replace(newPath, 'bncDemo', self.name);
            });
        } else {
            file.replace(item, 'bncDemo', self.name);
        }
    });
};

Init.makeHTML = function () {
    var name = path.join(this.workDir, 'debug', 'index.html');
    var cmd = util.format('BNC.ability.%s.init()', Init.name);
    var content = file.read(name);
    var writeContent = content
        .replace('{{title}}', Init.name)
        .replace('{{caller}}', cmd);
    file.write(name, writeContent);

    logger.log('You can preview in -> ' + name);
    logger.log('Use "bnc build" to debug the code');
};

Init.init();
